@@ -10,7 +10,7 @@ require Exporter;
 
 our @ISA = qw(Exporter AptPkg::hash);
 our @EXPORT = ();
-our $VERSION = 1.23;
+our $VERSION = 1.25;
 
 sub new
 {
@@ -54,6 +54,9 @@ sub get
     $value ? AptPkg::Cache::Package->new($value) : undef;
 }
 
+sub is_multi_arch { shift->_xs->MultiArchCache() }
+sub native_arch { shift->_xs->NativeArch() }
+
 package AptPkg::Cache::Iter;
 
 sub new
@@ -69,7 +72,7 @@ sub next
 {
     my $self = shift;
     my $obj = $$self or return;
-    my $key = $obj->Name;
+    my $key = $obj->FullName;
     $obj->Next or $$self = undef;
     $key;
 }
@@ -97,10 +100,16 @@ package AptPkg::Cache::Package;
 
 our @ISA = qw(AptPkg::hash::method);
 our @KEYS = qw(
-    Name Section VersionList CurrentVer RevDependsList ProvidesList
-    Index SelectedState InstState CurrentState Flags
+    Name FullName ShortName Arch Section VersionList CurrentVer RevDependsList
+    ProvidesList Index SelectedState InstState CurrentState Flags
 );
 
+sub ShortName
+{
+    # Same as Name for native, and FullName for non-native packages.
+    shift->_xs->FullName(1); # Pretty=true
+}
+
 sub VersionList
 {
     AptPkg::Cache::_make_class_list shift, 'AptPkg::Cache::Version';
@@ -128,8 +137,9 @@ package AptPkg::Cache::Version;
 
 our @ISA = qw(AptPkg::hash::method);
 our @KEYS = qw(
-    VerStr Section Arch ParentPkg DependsList ProvidesList FileList
-    InstalledSize Size Index Priority
+    VerStr Section Arch MultiArch ParentPkg DescriptionList
+    TranslatedDescription DependsList ProvidesList FileList InstalledSize
+    Size Index Priority
 );
 
 sub ParentPkg
@@ -137,6 +147,16 @@ sub ParentPkg
     AptPkg::Cache::_make_class shift, 'AptPkg::Cache::Package';
 }
 
+sub DescriptionList
+{
+    AptPkg::Cache::_make_class_list shift, 'AptPkg::Cache::Description';
+}
+
+sub TranslatedDescription
+{
+    AptPkg::Cache::_make_class shift, 'AptPkg::Cache::Description';
+}
+
 sub DependsList
 {
     AptPkg::Cache::_make_class_list shift, 'AptPkg::Cache::Depends';
@@ -181,6 +201,21 @@ sub OwnerPkg { AptPkg::Cache::_make_class shift, 'AptPkg::Cache::Package' }
 package AptPkg::Cache::Provides::Iter;
 our @ISA = qw(AptPkg::hash::method::iter);
 
+package AptPkg::Cache::Description;
+
+our @ISA = qw(AptPkg::hash::method);
+our @KEYS = qw(LanguageCode md5 FileList);
+
+sub FileList
+{
+    AptPkg::Cache::_make_class shift, 'AptPkg::Cache::DescFile';
+}
+
+
+package AptPkg::Cache::Description::Iter;
+our @ISA = qw(AptPkg::hash::method::iter);
+
+package AptPkg::Cache::PkgFile;
 package AptPkg::Cache::PkgFile;
 
 our @ISA = qw(AptPkg::hash::method);
@@ -201,6 +236,16 @@ sub File { AptPkg::Cache::_make_class shift, 'AptPkg::Cache::PkgFile' }
 package AptPkg::Cache::VerFile::Iter;
 our @ISA = qw(AptPkg::hash::method::iter);
 
+package AptPkg::Cache::DescFile;
+
+our @ISA = qw(AptPkg::hash::method);
+our @KEYS = qw(File);
+
+sub File { AptPkg::Cache::_make_class shift, 'AptPkg::Cache::PkgFile' }
+
+package AptPkg::Cache::DescFile::Iter;
+our @ISA = qw(AptPkg::hash::method::iter);
+
 1;
 
 __END__
@@ -264,9 +309,17 @@ additional information about packages.
 
 =item get, exists, keys
 
-These methods are used to implement the hashref abstraction: 
+These methods are used to implement the hashref abstraction:
 $obj->get($pack) and $obj->{$pack} are equivalent.
 
+=item is_multi_arch
+
+Cache is multi-arch enabled.
+
+=item native_arch
+
+Native architecture.
+
 =back
 
 =head2 AptPkg::Cache::Package
@@ -281,7 +334,18 @@ Implements the B<APT> pkgCache::PkgIterator class as a hash reference.
 
 =item Section
 
-Package name and section.
+=item Arch
+
+Package name, section and architecture.
+
+=item FullName
+
+Fully qualified name, including architecture.
+
+=item ShortName
+
+The shortest unambiguous package name: the same as C<Name> for native
+packages, and C<FullName> for non-native.
 
 =item SelectedState
 
@@ -328,7 +392,7 @@ current package.
 A comma separated list if flags:  C<Auto>, C<Essential> or
 C<Important>.
 
-In a numeric context, evaluates to a combination of AptPkg::Flag:: 
+In a numeric context, evaluates to a combination of AptPkg::Flag::
 constants.
 
 [Note:  the only one of these you need worry about is C<Essential>,
@@ -358,11 +422,29 @@ Implements the B<APT> pkgCache::VerIterator class as a hash reference.
 
 The package version, section and architecture.
 
+=item MultiArch
+
+Multi-arch state: C<None>, C<All>, C<Foreign>, C<Same>, C<Allowed>,
+C<AllForeign> or C<AllAllowed>.
+
+In a numeric context, evaluates to an AptPkg::Version:: constant.
+
 =item ParentPkg
 
 An AptPkg::Cache::Package objct describing the package providing this
 version.
 
+=item DescriptionList
+
+A list of AptCache::Cache::Description objects describing the files which
+descrie a package version.  The list includes both Package files and
+Translation files, which contain translated Description fields.
+
+=item TranslatedDescription
+
+An AptCache::Cache::Description object for the current locale, which will
+generally be a Translation file.
+
 =item DependsList
 
 A reference to an array of AptPkg::Cache::Depends objects describing
@@ -547,6 +629,21 @@ Internal B<APT> unique reference for the package file record.
 
 =back
 
+=head2 AptPkg::Cache::DescFile
+
+Implements the B<APT> pkgCache::DescFileIterator class as a hash
+reference.
+
+=head3 Keys
+
+=over 4
+
+=item File
+
+An AptPkg::Cache::PkgFile object describing the packages file.
+
+=back
+
 =head1 SEE ALSO
 
 AptPkg::Config(3pm), AptPkg::System(3pm), AptPkg(3pm),
