@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use AptPkg;
 
-our $VERSION = 1.1;
+our $VERSION = 1.2;
 
 sub lookup
 {
@@ -22,11 +22,20 @@ sub lookup
 	my $v = ($p->{VersionList} || [])->[0]	or return;
 	$pack = ($v->{FileList}    || [])->[0]	or return;
 	$extra{$_} = $v->{$_} for qw/Section VerStr/;
+
+	# Get translated ShortDesc and LongDesc
+	if (my $t = $v->{TranslatedDescription})
+	{
+	    if (my %e = $xs->Lookup($t->{FileList}->_xs))
+	    {
+		$extra{$_} = $e{$_} for grep /^(Long|Sort)Desc$/, keys %e;;
+	    }
+	}
     }
 
-    my @r = $xs->Lookup($pack->_xs) or return;
-    push @r, %extra;
-    wantarray ? @r : { @r };
+    my %r = $xs->Lookup($pack->_xs) or return;
+    $r{$_} = $extra{$_} for keys %extra;
+    wantarray ? %r : \%r;
 }
 
 1;
@@ -62,8 +71,8 @@ C<packages> method from an AptPkg::Cache object.
 Return a hash (or hash reference, depending on context) for the given
 package.
 
-I<PACK> may either be an AptPkg::Cache::VerFile object, or a package
-name.
+I<PACK> may either be an AptPkg::Cache::VerFile object, an
+AptPkg::Cache::DescFile object or a package name.
 
 The hash contains the following keys:
 
@@ -74,8 +83,13 @@ C<LongDesc> and C<Name>.
 
 =back
 
-with values taken from the packages file.  If I<PACK> is a package
-name, these additional values are set:
+with values taken from the packages or translation file.
+
+Note that C<LongDesc> is generally not useful for AptPkg::Cache::VerFile
+objects, which refer to the Packages file, as these no longer contain the full
+description (now in the Translation files).
+
+If I<PACK> is a package name, these additional values are set:
 
 =over 4
 
@@ -83,6 +97,14 @@ C<Section> and C<VerStr>.
 
 =back
 
+and the following values are overriden with the translated versions:
+
+=over 4
+
+C<ShortDesc> and C<LongDesc>.
+
+=back
+
 =back
 
 =head1 SEE ALSO
